/* vim: set textwidth=80 tabstop=4: */

/* Copyright (c) 2008 Michael Rasmussen (mir@datanom.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __CALDAV_UTILS_H__
#define __CALDAV_UTILS_H__

#include <glib.h>
#include <stdlib.h>
#include <curl/curl.h>
#include "caldav.h"

typedef struct _CALDAV_SETTINGS caldav_settings;
struct _CALDAV_SETTINGS {
	gchar* username;
	gchar* password;
	gchar* url;
	gchar* file;
	gboolean debug;
	char trace_ascii;
	CALDAV_ACTION ACTION;
	time_t start;
	time_t end;
};

typedef struct MemoryStruct memory_ptr;
struct MemoryStruct {
	char *memory;
	size_t size;
};

struct config_data {
	char trace_ascii;
};

void dump(const char* text, FILE* stream, unsigned char* ptr, size_t size, char nohex);
int my_trace(CURL* handle, curl_infotype type, unsigned char* data, size_t size, void* userp);
size_t WriteMemoryCallback(void* ptr, size_t size, size_t nmemb, void* data);
size_t WriteHeaderCallback(void* ptr, size_t size, size_t nmemb, void* data);
/*size_t ReadMemoryCallback(void* ptr, size_t size, size_t nmemb, void* data);*/
void init_caldav_settings(caldav_settings* settings);
void free_caldav_settings(caldav_settings* settings);
void parse_url(caldav_settings* settings, const char* url);
gchar* get_response_header(const char* header, gchar* headers);
gchar* parse_caldav_report(char* report, const char* element, const char* type);
gchar* get_caldav_datetime(time_t* time);
gchar* random_file_name(gchar* text);
gchar* verify_uid(gchar* object);
gchar* get_url(gchar* text);
gchar* get_host(gchar* url);
gchar* get_etag(gchar* text);
gchar* get_tag(const gchar* tag, gchar* text);

#endif
